/**
 // -------------------------------------
 //   Options (Build)
 // -------------------------------------
 */

"use strict";

var exports = module.exports = {
    // ----- Default ----- //
    default: {
        tasks: ['build', 'connect', 'watch']
    },
    // ----- Clean ----- //
    clean: {
        target: "./build"
    },
    // ----- Build ----- //
    build: {
        tasks: [],
        destination: 'build/'
    },
    // ----- Scss ----- //
    scss: {
        src: "./docs/assets/scss/*.scss",
        dest: "./build/assets/scss",
        settings: {
            includePaths: [
                './scss/',
                './vendor/'
            ],
            outputStyle: "nested",
            errLogToConsole: true
        }
    },
    // ----- Fonts ----- //
    fonts: {
        fontaswesome: {
            src: "./vendor/font-awesome/fonts/**",
            dest: "./build/assets/fonts/font-awesome/"
        },
        iconic: {
            src: "./vendor/foundation-apps/iconic/**",
            dest: "./build/assets/fonts/iconic/"
        }
    },
    // ----- Images ----- //
    images: {
        src: ["./docs/assets/img/**", "./img/**"],
        dest: "./build/assets/img",
        settings: {}
    },
    // ----- Html2Js ----- //
    html2Js: {
        src: ["./vendor/foundation-apps/js/angular/components/**/*.html"],
        dest: "./docs/assets/js",
        filename: "fultra.templates.js",
        settings: {
            moduleName: "fultra.templates",
            prefix: "components/"
        }
    },
    // ----- Lint ----- //
    lint: {
        scss: {
            targets: [
                './scss/*.scss',
                './docs/assets/scss/*.scss'
            ]
        },
        js: {
            targets: [
                './js/*.js',
                './docs/assets/js/app.js',
                './Gulpfile.js',
                './gulp/**/*.js'
            ]
        },
        css: {
            targets: [
                './build/assets/css/*.css',
                './dist/css/*.css'
            ]
        }
    },
    // ---- scripts ----- //
    scripts: {
        //Files to include in the final script
        src: [
            // './libs/vendor/jquery/dist/jquery.js',
            // Angular and deps
            './vendor/angular/angular.js',
            './vendor/angular-animate/angular-animate.js',
            './vendor/angular-ui-router/release/angular-ui-router.js',
            // Any Jquery elements
            './vendor/fastclick/lib/fastclick.js',
            './vendor/hammerjs/hammer.js',
            './vendor/tether/dist/js/tether.js',
            // Foundation Apps Components & Services
            './vendor/foundation-apps/js/angular/services/*.js',
            './vendor/foundation-apps/js/angular/components/**/*.js',
            './vendor/foundation-apps/js/angular/vendor/**/*.js',
            './vendor/foundation-apps/js/vendor/**/*.js',
            // Bring it all together with the fultra namespace
            './js/fultra.js',
            // All of the foundation html templates into a js cache module
            './docs/assets/js/fultra.templates.js',
            // Our generated routes
            './docs/assets/js/fultra.routes.js',
            // And finally our application specific scripts
            './docs/assets/js/app.js'
        ],
        // The destination of the final file
        dest: "./build/assets/js/",
        // The final name of the file
        filename: "app.js"
    },
    // ----- Html ----- //
    html: {
        src: [
            './docs/**/*.html',
            './docs/*.html'
        ],
        dest: "./build",
        settings: {
            processHtml: {
                process: true,
                environment: "dev",
                data: {
                    title: "Dev Version",
                    message: "This is Dev environment",
                    comment: "These comments will all be removed in the release environment"
                }
            },
            frontRouter: {
                path: "./docs/assets/js/fultra.routes.js",
                root: "./docs/"
            }
        }
    }
};
