/**
 // -------------------------------------
 //   Options (Release)
 // -------------------------------------
 */

"use strict";

var exports = module.exports = {
    // ----- Default ----- //
    default: {
        tasks: ['build']
    },
    // ----- Clean ----- //
    clean: {
        target: "./dist"
    },
    // ----- Build ----- //
    build: {
        tasks: [],
        destination: 'dist/'
    },
    // ----- Scss ----- //
    scss: {
        src: "./scss/*.scss",
        dest: "./dist/css",
        settings: {
            includePaths: [
                './scss/',
                './vendor/'
            ],
            outputStyle: "nested",
            errLogToConsole: true
        }
    },
    // ----- Fonts ----- //
    fonts: {
        fontaswesome:{
            src:"./vendor/font-awesome/fonts/**",
            dest:"./dist/fonts/font-awesome/"
        },
        iconic:{
            src:"./vendor/foundation-apps/iconic/**",
            dest:"./dist/fonts/iconic/"
        }
    },
    // ----- Images ----- //
    images: {
        src: ["./docs/assets/img/**","./img/**"],
        dest: "./dist/img",
        settings: {}
    },
    // ----- Html2Js ----- //
    html2Js: {
        src: ["./vendor/foundation-apps/js/angular/components/**/*.html"],
        dest: "./dist/js",
        filename: "fultra.templates.js",
        settings: {
            moduleName: "fultra.templates",
            prefix: "components/"
        }
    },
    // ----- Lint ----- //
    lint: {
        scss:{
            targets: [
                './scss/*.scss'
            ]
        },
        js:{
            targets: [
                './js/*.js',
                './dist/js/*.js',
                './Gulpfile.js',
                './gulp/**/*.js'
            ]
        },
        css: {
            targets: [
                './dist/css/*.css'
            ]
        }
    },
    // ---- scripts ----- //
    scripts: {
        //Files to include in the final script
        src: [
            // './libs/vendor/jquery/dist/jquery.js',
            // Angular and deps
            './vendor/angular/angular.js',
            './vendor/angular-animate/angular-animate.js',
            './vendor/angular-ui-router/release/angular-ui-router.js',
            // Any Jquery elements
            './vendor/fastclick/lib/fastclick.js',
            './vendor/hammerjs/hammer.js',
            './vendor/tether/dist/js/tether.js',
            // Foundation Apps Components & Services
            './vendor/foundation-apps/js/angular/services/*.js',
            './vendor/foundation-apps/js/angular/components/**/*.js',
            './vendor/foundation-apps/js/angular/vendor/**/*.js',
            './vendor/foundation-apps/js/vendor/**/*.js',
            // Bring it all together with the fultra namespace
            './js/fultra.js'
        ],
        // The destination of the final file
        dest: "./dist/js/",
        // The final name of the file
        filename: "fultra.js"
    },
    // ----- Html ----- //
    html: {}
};
